/* jd.c, algorithms from Explanatory Supplement to the
 *	  Astronomical Almanac, ch. 12, by L. E. Doggett
 */

#include <stdio.h> 
#include <stdlib.h> 
#include <math.h>
#include <time.h>
/*#include <dos.h>*/
#include <stddef.h>


void usage(); 

int  gregorian=1;             /* --> gregorian calendar; 0 --> julian calendar */ 
long jdtransition=2361222;    /* default transition is for Britain and colonies */ 
char *calendar[2];

#include "jd.h"
#include "noargs.c"
#include "gregcal.c"
#include "jdstring.c"
#include "weekday.c"



void
main( argc, argv )
int argc;
char *argv[];
{
  int i; 
  double xjd; 
  long   ijd;
  char *datestring;
  char datebuf[40];
  int year;
  int month;
  float fracday;
  float fday; 
  int day;
  

#ifdef debug      
  for (i=0; i<argc; ++i)
  {
    printf(" argc = %d, argv[%d] = %s \n", argc, i, argv[i] );
  }
#endif debug
  
  setCalendarTransition(); 
  calendar[0] = "julian";
  calendar[1] = "gregorian";

  if (argc == 1)
  {
    xjd = noargs(); 
    exit(0);
  }

  if (argc == 2)
  {
    xjd = atof( argv[1] ); 
    setGregorian( jdnoon(xjd) ); 
    xCalendarDate( xjd, datebuf, "%d-%d-%d %d:%d:%d" ); 

    datestring = datebuf;
    printf(" jd %12.2f  = % 9s, % 9s % 10s \n", xjd, calendar[gregorian], xWeekday(xjd), datestring ); 
    exit(0); 
  }
 
  if (argc == 4)
  {
    year = atoi( argv[1] );
    month = atoi( argv[2] );
    fday = atof( argv[3] );

    day = floor(fday); 
    ijd = CalendarToJD( year, month, day );
    xjd = ijd; 
    
    if ( strchr( argv[3], '.' ) != NULL)
    {
	fracday = fday - day;
	xjd += fracday - 0.5;
	printf(" % 9s date %s %d %d %6.2f  = %12.2f \n", calendar[gregorian], xWeekday(xjd), year, month, fday, xjd );
    }
    else 
    {
	printf(" % 9s date %s %d %d %d  = %ld \n", calendar[gregorian], xWeekday(xjd), year, month, (int) fday, (long) xjd );
    }
    exit(0); 
  }

  /* no parsing of the argument succeeded; so quote usage: */ 
  usage(); 
    
}



void
usage()
{
  printf(" usage: \n");
  printf(" jd [no arguments] \n");
  printf("     returns julian day number for current time \n");
  printf("     with calendar date for local and GMT \n"); 
  printf(" jd [julian day number] \n");
  printf("     returns (usually gregorian) calendar date for that julian day number \n");
  printf("     jd 2451545 --> 2000 1 1, i. e., year 2000, Jan 1 \n"); 
  printf(" jd year month day \n");
  printf("     converts to julian day number; \n");
  printf("     if the day has no decimal point, it is assumed to mean noon; \n");
  printf("     day with a decimal point --> it means decimal time from start of civil date \n"); 
  printf(" to set the calendar to gregorian or julian, see calendar.doc or setcal.c  \n");

}



